#!/usr/bin/env python

import pymongo
import os
import argparse
import multiprocessing as mp
from lib import utils

# Command line parsing
parser = argparse.ArgumentParser(
    description="Dump the tweets of a database to a JSON file")
parser.add_argument("-H", "--host", type=str, default="localhost")
parser.add_argument("-p", "--port", type=int, default=27017)
parser.add_argument("-s", "--pagesize", type=int, default=1000)
parser.add_argument("database", type=str)
args = parser.parse_args()

# Dirs and files
script_dir = os.path.dirname(__file__)
output_dir = os.path.join(script_dir, "pymongodump", args.database)
header_file = os.path.join(script_dir, "header.txt")

# MongoDB connection
client = pymongo.MongoClient(args.host, args.port)
database_tweets = client[args.database]["tweets"]

with open(header_file) as f:
    header = f.readline()
buffer_tweets = {}
num_page = 0

page_index = utils.get_page_index(database_tweets, args.pagesize)
client.close()


# Build a picklable function that we can pass to map
def write_page(
        page, host=args.host, port=args.port, database=args.database,
        pagesize=args.pagesize, header=header, outputdir=output_dir):
    utils.write_tweets_to_files(
        host, port, database, pagesize, header, output_dir, page)


# Make the computation
with mp.Pool() as pool:
    pool.map(write_page, page_index)
